pub trait Columnation: Sized {
type InnerRegion: Region<Item = Self>;
}Expand description
A type that can be stored in a columnar region.
This trait exists only to allow types to name the columnar region that should be used.
Required Associated Types
Sourcetype InnerRegion: Region<Item = Self>
type InnerRegion: Region<Item = Self>
The type of region capable of absorbing allocations owned by
the Self type. Note: not allocations of Self, but of the
things that it owns.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".